@@ -36,7 +36,13 @@ int main(int argc, char *argv[])
         else
         {
             qDebug() << "Asking it to offer to create a new widget.";
-            app.sendMessage(APP_MESSAGE_ADDWIDGET);
+	    QStringList result;
+	    result = app.arguments().filter(".qml");
+	    if (result.size() == 1 && QFile(result.last()).exists()) {
+	      app.sendMessage(QFileInfo(result.last()).absoluteFilePath());
+	    } else {
+	      app.sendMessage(APP_MESSAGE_SETWIDGET);	      
+	    }
             return 0;
         }
     }
@@ -54,13 +60,16 @@ int main(int argc, char *argv[])
         qDebug() << "Restoring all widgets";
         QeMaemo5DynamicWidgetHelper::globalInstance()->restoreWidgets<QuickWidget>();
     }
-
-    if (!app.arguments().contains("in-background"))
+    QStringList result;
+    result = app.arguments().filter(".qml");
+    if (result.size() == 1 && QFile(result.last()).exists()) {
+      app.sendMessage(QFileInfo(result.last()).absoluteFilePath());
+    } else if (!app.arguments().contains("in-background"))
     {
         // setting for new widget
         QuickWidgetSettings settingsDialog;
         settingsDialog.exec();
-        //app.sendMessage(APP_MESSAGE_ADDWIDGET);
+        //app.sendMessage(APP_MESSAGE_SETWIDGET);
     }
     return app.exec();
 }
