@@ -145,6 +145,12 @@ endl;
     size_ = QSize(errwdgt->width(), errwdgt->height());
 }
 
+//disable base class widget's paint method
+void QuickWidget::paintEvent(QPaintEvent *event)
+{
+    QWidget::paintEvent(event);
+}
+
 void QuickWidget::resizer(const QSize& size)
 {
   if (size_.isValid())
@@ -152,4 +158,3 @@ void QuickWidget::resizer(const QSize& size)
       resize(size);
   }
 }
-
